==> tipfy.ext.sharded_counter-0.1.zip: tipfy.ext.sharded_counter-0.1/setup.py <==
# -*- coding: utf-8 -*-
"""
tipfy.ext.sharded_counter
~~~~~~~~~~~~~~~~~~~~~~~~~

A general purpose sharded counter implementation for App Engine.

Documentation is available at
`http://www.tipfy.org/wiki/extensions/shardedcounter/ <http://www.tipfy.org/wiki/extensions/shardedcounter/>`_.

Links
-----
* `Tipfy <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Source Code Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.sharded_counter',
    version = '0.1',
    license = 'Apache',
    url = 'http://www.tipfy.org/',
    description = 'A general purpose sharded counter implementation for the App Engine',
    long_description = __doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms = 'any',
    packages = [
        'tipfy',
        'tipfy.ext',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data = True,
    install_requires = [
        'tipfy',
    ],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> tipfy.ext.sharded_counter-0.2.zip: tipfy.ext.sharded_counter-0.2/setup.py <==
# -*- coding: utf-8 -*-
"""
tipfy.ext.sharded_counter
~~~~~~~~~~~~~~~~~~~~~~~~~

A general purpose sharded counter implementation for App Engine.

Documentation is available at
`http://www.tipfy.org/wiki/extensions/shardedcounter/ <http://www.tipfy.org/wiki/extensions/shardedcounter/>`_.

Links
-----
* `Tipfy <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Source Code Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.sharded_counter',
    version = '0.2',
    license = 'Apache',
    url = 'http://www.tipfy.org/',
    description = 'A general purpose sharded counter implementation for App Engine',
    long_description = __doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms = 'any',
    packages = [
        'tipfy',
        'tipfy.ext',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data = True,
    install_requires = [
        'tipfy',
    ],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
